# coding: utf-8

# flake8: noqa

"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
from __future__ import absolute_import

# import models into model package
from ntnx_dataprotection_py_client.models.OneOfcommon.v1.config.KVPairvalue import KVPairvalue
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ChangedRegionsListApiResponsedata import ChangedRegionsListApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ConsistencyGroupApiResponsedata import ConsistencyGroupApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ConsistencyGroupListApiResponsedata import ConsistencyGroupListApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ConsistencyGroupMigrateApiResponsedata import ConsistencyGroupMigrateApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.CreateConsistencyGroupRecoveryPointApiResponsedata import CreateConsistencyGroupRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.CreateRecoveryPointApiResponsedata import CreateRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.DeleteConsistencyGroupApiResponsedata import DeleteConsistencyGroupApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.DeleteRecoveryPointApiResponsedata import DeleteRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.DiskRecoveryPointApiResponsedata import DiskRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.DiskRecoveryPointListApiResponsedata import DiskRecoveryPointListApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ProtectedResourceApiResponsedata import ProtectedResourceApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ProtectedResourcePromoteApiResponsedata import ProtectedResourcePromoteApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ProtectedResourceRestoreApiResponsedata import ProtectedResourceRestoreApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointApiResponsedata import RecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointListApiResponsedata import RecoveryPointListApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointReplicateApiResponsedata import RecoveryPointReplicateApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointRestoreApiResponsedata import RecoveryPointRestoreApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.SyncedVolumeGroupByIdApiResponsedata import SyncedVolumeGroupByIdApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.SynchronousReplicaPromoteApiResponsedata import SynchronousReplicaPromoteApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.UpdateRecoveryPointExpirationTimeApiResponsedata import UpdateRecoveryPointExpirationTimeApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.VMRecoveryPointApiResponsedata import VMRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.VMRecoveryPointListApiResponsedata import VMRecoveryPointListApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ValidateRestoreVmRecoveryPointApiResponsedata import ValidateRestoreVmRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.VmRecoveryPointRestoreApiResponsedata import VmRecoveryPointRestoreApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.VolumeGroupRecoveryPointApiResponsedata import VolumeGroupRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.VolumeGroupRecoveryPointListApiResponsedata import VolumeGroupRecoveryPointListApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.VolumeGroupRecoveryPointRestoreApiResponsedata import VolumeGroupRecoveryPointRestoreApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.WitnessApiResponsedata import WitnessApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.error.ErrorResponseerror import ErrorResponseerror
from ntnx_dataprotection_py_client.models.common.v1.config.Flag import Flag
from ntnx_dataprotection_py_client.models.common.v1.config.IPv4Address import IPv4Address
from ntnx_dataprotection_py_client.models.common.v1.config.KVPair import KVPair
from ntnx_dataprotection_py_client.models.common.v1.config.Message import Message
from ntnx_dataprotection_py_client.models.common.v1.config.MessageSeverity import MessageSeverity
from ntnx_dataprotection_py_client.models.common.v1.config.TenantAwareModel import TenantAwareModel
from ntnx_dataprotection_py_client.models.common.v1.response.ApiLink import ApiLink
from ntnx_dataprotection_py_client.models.common.v1.response.ApiResponseMetadata import ApiResponseMetadata
from ntnx_dataprotection_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.BaseRecoveryPoint import BaseRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.RecoveryPointStatus import RecoveryPointStatus
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.RecoveryPointType import RecoveryPointType
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.VendorSpecificProperty import VendorSpecificProperty
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.AhvVmOverrideSpec import AhvVmOverrideSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.Category import Category
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ChangedRegions import ChangedRegions
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ChangedRegionsListApiResponse import ChangedRegionsListApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ClusterReference import ClusterReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroup import ConsistencyGroup
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupApiResponse import ConsistencyGroupApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupListApiResponse import ConsistencyGroupListApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMember import ConsistencyGroupMember
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMemberType import ConsistencyGroupMemberType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMigrateApiResponse import ConsistencyGroupMigrateApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMigrationSpec import ConsistencyGroupMigrationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupProjection import ConsistencyGroupProjection
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupRecoveryPointSpec import ConsistencyGroupRecoveryPointSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.CreateConsistencyGroupRecoveryPointApiResponse import CreateConsistencyGroupRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.CreateRecoveryPointApiResponse import CreateRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DataProtectionInfo import DataProtectionInfo
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DataProtectionSiteReference import DataProtectionSiteReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DeleteConsistencyGroupApiResponse import DeleteConsistencyGroupApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DeleteRecoveryPointApiResponse import DeleteRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DisasterRecoveryLocation import DisasterRecoveryLocation
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.Disk import Disk
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DiskRecoveryPoint import DiskRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DiskRecoveryPointApiResponse import DiskRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DiskRecoveryPointListApiResponse import DiskRecoveryPointListApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.EsxiVmOverrideSpec import EsxiVmOverrideSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HardwareArchitecture import HardwareArchitecture
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HostReference import HostReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HostType import HostType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HypervisorType import HypervisorType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.IpAddress import IpAddress
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.LocationReference import LocationReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.PowerState import PowerState
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResource import ProtectedResource
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceApiResponse import ProtectedResourceApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceEntityType import ProtectedResourceEntityType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourcePromoteApiResponse import ProtectedResourcePromoteApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceReplicationStatus import ProtectedResourceReplicationStatus
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceRestoreApiResponse import ProtectedResourceRestoreApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceRestoreSpec import ProtectedResourceRestoreSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryInfo import RecoveryInfo
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPoint import RecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointApiResponse import RecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointListApiResponse import RecoveryPointListApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointReplicateApiResponse import RecoveryPointReplicateApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointReplicationSpec import RecoveryPointReplicationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointRestorationSpec import RecoveryPointRestorationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointRestoreApiResponse import RecoveryPointRestoreApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.Regions import Regions
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ReplicationState import ReplicationState
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RestorableTimeRange import RestorableTimeRange
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SetExpirationTimeSpec import SetExpirationTimeSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SiteReference import SiteReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.Subnet import Subnet
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SyncedVolumeGroupByIdApiResponse import SyncedVolumeGroupByIdApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SynchronousReplicaPromoteApiResponse import SynchronousReplicaPromoteApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.UpdateRecoveryPointExpirationTimeApiResponse import UpdateRecoveryPointExpirationTimeApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VMRecoveryPoint import VMRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VMRecoveryPointApiResponse import VMRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VMRecoveryPointListApiResponse import VMRecoveryPointListApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ValidateRecoveryPointResult import ValidateRecoveryPointResult
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ValidateRestoreVmRecoveryPointApiResponse import ValidateRestoreVmRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ValidationSeverity import ValidationSeverity
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.Vm import Vm
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmRecoveryPointRestorationSpec import VmRecoveryPointRestorationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmRecoveryPointRestoreApiResponse import VmRecoveryPointRestoreApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmRecoveryPointRestoreOverride import VmRecoveryPointRestoreOverride
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmSubRecoveryPoint import VmSubRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmSubRecoveryPointProjection import VmSubRecoveryPointProjection
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroup import VolumeGroup
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupOverrideSpec import VolumeGroupOverrideSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPoint import VolumeGroupRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPointApiResponse import VolumeGroupRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPointListApiResponse import VolumeGroupRecoveryPointListApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPointRestorationSpec import VolumeGroupRecoveryPointRestorationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPointRestoreApiResponse import VolumeGroupRecoveryPointRestoreApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPointRestoreOverride import VolumeGroupRecoveryPointRestoreOverride
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupSubRecoveryPoint import VolumeGroupSubRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupSubRecoveryPointProjection import VolumeGroupSubRecoveryPointProjection
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupSyncContext import VolumeGroupSyncContext
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VpcReference import VpcReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.Witness import Witness
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.WitnessApiResponse import WitnessApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.WitnessAvailabilityStatus import WitnessAvailabilityStatus
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.AppMessage import AppMessage
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.ErrorResponse import ErrorResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.SchemaValidationError import SchemaValidationError
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.SchemaValidationErrorMessage import SchemaValidationErrorMessage
from ntnx_dataprotection_py_client.models.prism.v4.config.TaskReference import TaskReference
from ntnx_dataprotection_py_client.models.storage.v4.config.Task import Task
from ntnx_dataprotection_py_client.api_response import ApiResponse
