# coding: utf-8


"""
IGNORE:
    Nutanix Dataprotection Versioned APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1-alpha-4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmSubRecoveryPoint import VmSubRecoveryPoint  # noqa: F401,E501

class VmSubRecoveryPointProjection(VmSubRecoveryPoint):

    """

    :param vm_recovery_point_id: (:attr:`vm_recovery_point_id`) The external identifier that can be used to retrieve the VM Recovery point using its URL.
    :type vm_recovery_point_id: 
    :param consistency_group_ext_id: (:attr:`consistency_group_ext_id`) External identifier of the Consistency group which the entity was part of at the time of Recovery point creation.
    :type consistency_group_ext_id: 
    :param location_agnostic_id: (:attr:`location_agnostic_id`) Location agnostic identifier of the Recovery point. This identifier is used to identify the same instances of a Recovery point across different sites.
    :type location_agnostic_id: 
    :param vm_ext_id: (:attr:`vm_ext_id`) VM external identifier which is captured as part of this Recovery point.
    :type vm_ext_id: 
    :param vm_categories: (:attr:`vm_categories`) Category key-value pairs associated with the VM at the time of Recovery point creation. The category key and value are separated by '/'. For example, a category with key 'dept' and value 'hr' will be represented as 'dept/hr'.
    :type vm_categories: 

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'vm_recovery_point_id': 'str',
        'consistency_group_ext_id': 'str',
        'location_agnostic_id': 'str',
        'vm_ext_id': 'str',
        'vm_categories': 'list[str]',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'vm_recovery_point_id': 'vmRecoveryPointId',
        'consistency_group_ext_id': 'consistencyGroupExtId',
        'location_agnostic_id': 'locationAgnosticId',
        'vm_ext_id': 'vmExtId',
        'vm_categories': 'vmCategories',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, vm_recovery_point_id=None, consistency_group_ext_id=None, location_agnostic_id=None, vm_ext_id=None, vm_categories=None, *args, **kwargs):  # noqa: E501
        VmSubRecoveryPoint.__init__(self, vm_recovery_point_id, consistency_group_ext_id, location_agnostic_id, vm_ext_id, vm_categories, *args, **kwargs)
        self.discriminator = None

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.VmSubRecoveryPointProjection'

    def _initialize_fq_object_type(self):
        return 'dataprotection.v4.r0.a4.config.VmSubRecoveryPointProjection'


    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}

        for attr, attr_type in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize))
                    if hasattr(item[1], "_to_dict") else item,
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(VmSubRecoveryPointProjection, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VmSubRecoveryPointProjection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

